@@ -8,24 +8,19 @@
  *
  */
 
-/* F90 pointers are not true pointers.  Instead they are simply names that 
- serve as aliases for normal FORTRAN variables.  The only way I could think
- of to pass the c-malloc'ed pointer into the F90 pointer was to disguise
- it as a normal FORTRAN variable by passing it as a subroutine argument.
-*/
-
 #include <Python.h> /* make sure Python.h is first */
 #include "ferret.h"
+#include "FerMem.h"
 
+void FORTRAN(get_ws_mem)(int *index, int *alen, int *status)
 /*
   input  - index:  Ferret ws index at which to store the array pointer
   input  - alen:   array length
 */
-void FORTRAN(get_ws_mem)( int *index, long *alen, int *status )
 {
   double *pointer;
 
-  pointer = (double *) PyMem_Malloc(sizeof(double) * (*alen));
+  pointer = (double *) FerMem_Malloc(sizeof(double) * (*alen), __FILE__, __LINE__);
 
   if (pointer)
     {
