@@ -54,24 +54,27 @@
  *       char *data;
  */
 
+/* *acm   9/06 v600 - add stdlib.h wherever there is stdio.h for altix build*/ 
+
 #include <Python.h> /* make sure Python.h is first */
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
 #include "ferret.h"
+#include "FerMem.h"
 #include "list.h"
 
 
-LIST *list_init(void)
+LIST *list_init(char *filename, int linenum)
 {
    LIST *list;
 
    /* Allocate, initialize, and return a new list. */
-   list = (LIST *) PyMem_Malloc(sizeof(LIST));
+   list = (LIST *) FerMem_Malloc(sizeof(LIST), filename, linenum);
    list->size = 0;
-   list->front = NULL;;
-   list->rear = NULL;;
-   list->curr = NULL;;
+   list->front = NULL;
+   list->rear = NULL;
+   list->curr = NULL;
    return(list);
 }
 
@@ -165,14 +168,14 @@ int list_size(LIST *list)
  * #endif
  */
 
-static LIST_ELEMENT *list_create_element(char *data, int bytes)
+static LIST_ELEMENT *list_create_element(char *data, int bytes, char *filename, int linenum)
 {
    LIST_ELEMENT *new;
 
    /* Allocate storage for the new node and its data.  Return NULL if
     * unable to allocate.
     */
-   new = (LIST_ELEMENT *) PyMem_Malloc(sizeof(LIST_ELEMENT));
+   new = (LIST_ELEMENT *) FerMem_Malloc(sizeof(LIST_ELEMENT), filename, linenum);
    if (new == NULL) {
       return(NULL);
    }
@@ -181,8 +184,9 @@ static LIST_ELEMENT *list_create_element(char *data, int bytes)
     * Then either copy the data or just the reference into the node.
     */
    if (bytes > 0) {
-      new->data = (char *) PyMem_Malloc(bytes);
+      new->data = (char *) FerMem_Malloc(bytes, filename, linenum);
       if (new->data == NULL) {
+         FerMem_Free(new, filename, linenum);
 	 return(NULL);
       }
       (void) memcpy(new->data, data, bytes);
@@ -195,12 +199,12 @@ static LIST_ELEMENT *list_create_element(char *data, int bytes)
 }
 
 
-char *list_insert_before(LIST *list, char *data, int bytes)
+char *list_insert_before(LIST *list, char *data, int bytes, char *filename, int linenum)
 {
    LIST_ELEMENT *new;
 
    /* Allocate storage for the new element and its data.*/
-   new = list_create_element(data, bytes);
+   new = list_create_element(data, bytes, filename, linenum);
    if (new == NULL)
       return(NULL);
 
@@ -236,12 +240,12 @@ char *list_insert_before(LIST *list, char *data, int bytes)
 }
 
 
-char *list_insert_after(LIST *list, char *data, int bytes)
+char *list_insert_after(LIST *list, char *data, int bytes, char *filename, int linenum)
 {
    LIST_ELEMENT *new;
 
    /* Allocate storage for the new element and its data.*/
-   new = list_create_element(data, bytes);
+   new = list_create_element(data, bytes, filename, linenum);
    if (new == NULL)
       return(NULL);
 
@@ -277,20 +281,20 @@ char *list_insert_after(LIST *list, char *data, int bytes)
 }
 
 
-static char *list_remove_single(LIST *list)
+static char *list_remove_single(LIST *list, char *filename, int linenum)
 {
    char *data;
 
    /* The list has one element.  Easy. */
    data = list->curr->data;
-   PyMem_Free(list->curr);
+   FerMem_Free(list->curr, filename, linenum);
    list->front = list->rear = list->curr = NULL;
    list->size--;
    return (data);
 }
 
 
-char *list_remove_front(LIST *list)
+char *list_remove_front(LIST *list, char *filename, int linenum)
 {
    LIST_ELEMENT *temp;
    char *data;
@@ -304,7 +308,7 @@ char *list_remove_front(LIST *list)
    }
    else if (list->front == list->rear) {
       /* List has only one element.  Easy. */
-      data = list_remove_single(list);
+      data = list_remove_single(list, filename, linenum);
    }
    else {
       /* List has more than one element.  Make sure to check if curr
@@ -316,7 +320,7 @@ char *list_remove_front(LIST *list)
       list->front = temp->next;
       if (list->curr == temp)
 	 list->curr = temp->next;
-      PyMem_Free(temp);
+      FerMem_Free(temp, filename, linenum);
       list->size--;
    }
 
@@ -324,7 +328,7 @@ char *list_remove_front(LIST *list)
 }
 
 
-char *list_remove_rear(LIST *list)
+char *list_remove_rear(LIST *list, char *filename, int linenum)
 {
    LIST_ELEMENT *temp;
    char *data;
@@ -338,7 +342,7 @@ char *list_remove_rear(LIST *list)
    }
    else if (list->front == list->rear) {
       /* List has only one element.  Easy. */
-      data = list_remove_single(list);
+      data = list_remove_single(list, filename, linenum);
    }
    else {
       /* List has more than one element.  Make sure to check if curr
@@ -350,7 +354,7 @@ char *list_remove_rear(LIST *list)
       list->rear = temp->prev;
       if (list->curr == temp)
 	 list->curr = temp->prev;
-      PyMem_Free(temp);
+      FerMem_Free(temp, filename, linenum);
       list->size--;
    }
 
@@ -358,7 +362,7 @@ char *list_remove_rear(LIST *list)
 }
 
 
-char *list_remove_curr(LIST *list)
+char *list_remove_curr(LIST *list, char *filename, int linenum)
 {
    LIST_ELEMENT *temp;
    char *data;
@@ -374,15 +378,15 @@ char *list_remove_curr(LIST *list)
    }
    else if (list->front == list->rear) {
       /* The list has one element.  Easy. */
-      data = list_remove_single(list);
+      data = list_remove_single(list, filename, linenum);
    }
    else if (list->curr == list->front) {
       /* Removing front element.  Easy. */
-      data = list_remove_front(list);
+      data = list_remove_front(list, filename, linenum);
    }
    else if (list->curr == list->rear) {
       /* Removing from the rear.  Easy.*/
-      data = list_remove_rear(list);
+      data = list_remove_rear(list, filename, linenum);
    }
    else {
       /* Otherwise.  Must be inside a 3-element or larger list. */
@@ -391,7 +395,7 @@ char *list_remove_curr(LIST *list)
       temp->next->prev = temp->prev;
       temp->prev->next = temp->next;
       list->curr = temp->next;
-      PyMem_Free(temp);
+      FerMem_Free(temp, filename, linenum);
       list->size--;
    }
 
@@ -455,7 +459,7 @@ int list_traverse(LIST *list, char *data, int (*func)(char *, char *), int opts)
 }
 
 
-void list_free(LIST *list, void (*dealloc)(char *))
+void list_free(LIST *list, void (*dealloc)(char *), char *filename, int linenum)
 {
    char *data;
 
@@ -466,13 +470,13 @@ void list_free(LIST *list, void (*dealloc)(char *))
     */
    list_mvfront(list);
    while (! list_empty(list)) {
-      data = list_remove_front(list);
+      data = list_remove_front(list, filename, linenum);
       /* Apply either no deallocation function to each node, our own, or
        * a user-supplied version.
        */
       if ( dealloc != LIST_NODEALLOC ) {
 	 if ( dealloc == LIST_DEALLOC ) {
-	    PyMem_Free(data);
+	    FerMem_Free(data, filename, linenum);
 	 }
 	 else {
 	    (*dealloc)(data);
@@ -480,5 +484,5 @@ void list_free(LIST *list, void (*dealloc)(char *))
       }
    }
 
-   PyMem_Free(list);
+   FerMem_Free(list, filename, linenum);
 }
