@@ -41,21 +41,28 @@
 
 #include <Python.h> /* make sure Python.h is first */
 #include <stdlib.h>
+#include <string.h>
+#include "fmtprotos.h"
 #include "deleted_list.h"
+#include "FerMem.h"
 
-void deleted_list_clear_(void * deleted_list_header)
+void FORTRAN(deleted_list_clear)(void **deleted_list_header)
 {
-   int i,j;
+   DLHead *head;
    int array_size;
-   DLHead * head;
+   int j;
 
-   head = *((DLHead**)deleted_list_header);
-   array_size = head->array_size;
-   if(head){
-       for(j=1;j<=array_size;j++)
-         free(head->ptr_table[j-1]);
-       free(head->ptr_table);
+   head = *deleted_list_header;
+   if ( head != NULL ) {
+       array_size = head->array_size;
+       for (j = 0; j < array_size; j++) {
+           FerMem_Free(head->ptr_table[j], __FILE__, __LINE__);
+           head->ptr_table[j] = NULL;
+       }
+       FerMem_Free(head->ptr_table, __FILE__, __LINE__);
+       memset(head, 0, sizeof(DLHead));
+       FerMem_Free(head, __FILE__, __LINE__);
+       *deleted_list_header = NULL;
    }
-   *((int*)deleted_list_header)=0;
 }
 
