@@ -39,6 +39,7 @@
 
 #include <Python.h> /* make sure Python.h is first */
 #include <stdio.h>
+#include "fmtprotos.h"
 #include "string_array.h"
 
 typedef  unsigned long  int  ub4;   /* unsigned 4-byte quantities */
@@ -116,11 +117,13 @@ acceptable.  Do NOT use for cryptographic purposes.
 --------------------------------------------------------------------
 */
 
-int string_array_hash( k, length, initval, range)
-register ub1 *k;        /* the key */
-register ub4  length;   /* the length of the key */
-register ub4  initval;  /* the previous hash, or an arbitrary value */
-register int range;
+int string_array_hash(ub1 *k, ub4 length, ub4 initval, int range)
+/*
+    k; pointer to the key
+    length;   the length of the key 
+    initval;  the previous hash, or an arbitrary value
+    range;
+ */
 {
    register ub4 a,b,c,len;
    register int result;
