@@ -5,6 +5,8 @@ and also serves as a coding example of using this class.
 @author: Karl Smith
 '''
 
+from __future__ import print_function
+
 import numpy
 import ESMP
 from esmpcontrol import ESMPControl
@@ -198,20 +200,20 @@ def printDiffs(grid_lons, grid_lats, undef_val, max_negl,
     for (_, lon, lat, expect, found) in diff_list:
         if expect == undef_val:
             num_not_undef += 1
-            print "lon = %#7.3f, lat = %7.3f, expect =  undef, found = %#8.5f" \
-                  % (lon, lat, found)
+            print("lon = %#7.3f, lat = %7.3f, expect =  undef, found = %#8.5f" \
+                  % (lon, lat, found))
         elif found == undef_val:
             num_undef += 1
-            print "lon = %#7.3f, lat = %7.3f, expect = %#8.5f, found =  undef" \
-                  % (lon, lat, expect)
+            print("lon = %#7.3f, lat = %7.3f, expect = %#8.5f, found =  undef" \
+                  % (lon, lat, expect))
         else:
             num_diff += 1
-            print "lon = %#7.3f, lat = %7.3f, expect = %#8.5f, found = %#8.5f, " \
-                  "diff = %#8.5f" % (lon, lat, expect, found, found - expect)
-    print "%3d undefined when defined might be expected" % num_undef
-    print "%3d with absolute difference > %#.5f" % (num_diff, max_negl)
-    print "%3d defined when undefined expected" % num_not_undef
-    print "%3d values in the grid" % (expect_data.shape[0] * expect_data.shape[1])
+            print("lon = %#7.3f, lat = %7.3f, expect = %#8.5f, found = %#8.5f, " \
+                  "diff = %#8.5f" % (lon, lat, expect, found, found - expect))
+    print("%3d undefined when defined might be expected" % num_undef)
+    print("%3d with absolute difference > %#.5f" % (num_diff, max_negl))
+    print("%3d defined when undefined expected" % num_not_undef)
+    print("%3d values in the grid" % (expect_data.shape[0] * expect_data.shape[1]))
 
 
 # main routine - for testing "by hand"
@@ -279,16 +281,16 @@ if __name__ == '__main__':
     # Regrid from curvilinear to rectilinear using the bilinear method
     rect_regrid_data = regridder.regridCurvToRect(undef_val, ESMP.ESMP_REGRIDMETHOD_BILINEAR)
     # Print the differences between the expected and regrid data
-    print ""
-    print "analytic (expect) versus bilinear regridded (found) differences"
+    print("")
+    print("analytic (expect) versus bilinear regridded (found) differences")
     printDiffs(rect_2d_center_lons, rect_2d_center_lats, undef_val, max_negl,
                rect_expect_data, rect_regrid_data)
 
     # Regrid from curvilinear to rectilinear using the patch method
     rect_regrid_data = regridder.regridCurvToRect(undef_val, ESMP.ESMP_REGRIDMETHOD_PATCH)
     # Print the differences between the expected and regrid data
-    print ""
-    print "analytic (expect) versus patch regridded (found) differences"
+    print("")
+    print("analytic (expect) versus patch regridded (found) differences")
     printDiffs(rect_2d_center_lons, rect_2d_center_lats, undef_val, max_negl,
                rect_expect_data, rect_regrid_data)
 
@@ -296,8 +298,8 @@ if __name__ == '__main__':
     # Corners required for this method
     rect_regrid_data = regridder.regridCurvToRect(undef_val, ESMP.ESMP_REGRIDMETHOD_CONSERVE)
     # Print the differences between the expected and regrid data
-    print ""
-    print "analytic (expect) versus conserve regridded (found) differences"
+    print("")
+    print("analytic (expect) versus conserve regridded (found) differences")
     printDiffs(rect_2d_center_lons, rect_2d_center_lats, undef_val, max_negl,
                rect_expect_data, rect_regrid_data)
 
